@@ -104,10 +104,10 @@ Parse_Options parse_options_create(void)
 	po->cost_model.compare_fn = &VDAL_compare_parse;
 	po->cost_model.type = VDAL;
 #endif /* USE_CORPUS */
-	po->short_length = 6;
+	po->short_length = 10;
 	po->all_short = FALSE;
 	po->twopass_length = 30;
-	po->max_sentence_length = 170;
+	po->max_sentence_length = MAX_SENTENCE-3;
 	po->resources = resources_create();
 	po->display_short = TRUE;
 	po->display_word_subscripts = TRUE;
@@ -640,7 +640,7 @@ static void post_process_linkages(Sentence sent, Parse_Options opts)
 	{
 		for (in=0; in < N_linkages_alloced; in++)
 		{
-			extract_links(indices[in], sent->null_count, sent->parse_info);
+			extract_links(indices[in], sent->parse_info);
 #ifdef USE_FAT_LINKAGES
 			if (set_has_fat_down(sent))
 			{
@@ -664,7 +664,7 @@ static void post_process_linkages(Sentence sent, Parse_Options opts)
 	for (in=0; in < N_linkages_alloced; in++)
 	{
 		Linkage_info *lifo = &link_info[N_linkages_post_processed];
-		extract_links(indices[in], sent->null_count, sent->parse_info);
+		extract_links(indices[in], sent->parse_info);
 #ifdef USE_FAT_LINKAGES
 		lifo->fat = FALSE;
 		lifo->canonical = TRUE;
@@ -1011,12 +1011,12 @@ int sentence_nth_word_has_disjunction(Sentence sent, int i)
  * It checks that the actual stem+suffix, when concatenated, restores
  * the original word.  This is a work-around for somewhat sloppy
  * dictionaries, which aren't entirely careful with making sure
- * that the stem+suffix links are unique. Here's an illustrartion of
+ * that the stem+suffix links are unique. Here's an illustration of
  * the problem: The word Russian "тест" can be split into 
  * тест.= =.ndmsi and also тес.= =т.amss The, during linkage, 
  * тес.= and =.ndmsi are linked -- but this is not the original word; 
  * its junk.  This routine marks such linkages as 'bad'.  Really, the
- * dictionary should eb fixed ,, but what the hell. This isn't hard.
+ * dictionary should be fixed, but what the hell. This isn't hard.
  */
 static void sane_morphism(Sentence sent, Parse_Options opts)
 {
@@ -1026,7 +1026,7 @@ static void sane_morphism(Sentence sent, Parse_Options opts)
 	for (lk = 0; lk < sent->num_linkages_alloced; lk++)
 	{
 		Linkage_info *lifo = &sent->link_info[lk];
-		extract_links(lifo->index, sent->null_count, pi);
+		extract_links(lifo->index, pi);
 		for (i=0; i<sent->length; i++)
 		{
 			const char *djw;
@@ -1057,10 +1057,18 @@ static void sane_morphism(Sentence sent, Parse_Options opts)
 					continue;
 			}
 
+			/* If this word isn't a stem, and the next word isn't
+			 * a suffix, there's nothing to check. */
+			len = strlen(djw);
+			if ((INFIX_MARK != djw[len-1]) &&
+			    ((i+1) < sent->length) && 
+			    (NULL != pi->chosen_disjuncts[i+1]) &&
+			    (INFIX_MARK != pi->chosen_disjuncts[i+1]->string[0]))
+				continue;
+
 			/* If the next word is a suffix, and, when united with
 			 * the stem, it recreates the original word, then we
 			 * are very happy, and keep going. */
-			len = strlen(djw);
 			if ((INFIX_MARK == djw[len-1]) &&
 			    ((i+1) < sent->length) && 
 			    (NULL != pi->chosen_disjuncts[i+1]) &&
@@ -1215,6 +1223,7 @@ int sentence_parse(Sentence sent, Parse_Options opts)
 	}
 	print_time(opts, "Finished parse");
 
+	assert(0 <= sent->num_valid_linkages, "Miscount of valid linkages!")
 	return sent->num_valid_linkages;
 }
 
@@ -1251,7 +1260,7 @@ Linkage linkage_create(int k, Sentence sent, Parse_Options opts)
 	linkage->dis_con_tree = NULL;
 #endif /* USE_FAT_LINKAGES */
 
-	extract_links(sent->link_info[k].index, sent->null_count, sent->parse_info);
+	extract_links(sent->link_info[k].index, sent->parse_info);
 	compute_chosen_words(sent, linkage);
 
 #ifdef USE_FAT_LINKAGES
