@@ -14,6 +14,7 @@
 #include <stdio.h>
 #include <stdlib.h>
 #include "link-includes.h"
+#include "read-dict.h"  /* For Boolean */
 #include "spellcheck.h"
 #include "utilities.h"  /* For Win32 compatibility */
 
@@ -28,6 +29,10 @@ static const char *hunspell_dict_dirs[] = {
 	"/usr/share/hunspell/dicts",
 	"/usr/local/share/myspell/dicts",
 	"/usr/local/share/hunspell/dicts",
+	"/usr/share/myspell",
+	"/usr/share/hunspell",
+	"/usr/local/share/myspell",
+	"/usr/local/share/hunspell",
 	HUNSPELL_DICT_DIR	
 };
 
@@ -55,8 +60,9 @@ void * spellcheck_create(const char * lang)
 		if (0 != strcmp(lang, spellcheck_lang_mapping[i])) continue;
 
 		/* check in each hunspell_dict_dir if the files exist */
-		for (j = 0; j < sizeof(hunspell_dict_dirs); ++j)
+		for (j = 0; j < sizeof(hunspell_dict_dirs)/sizeof(char *); ++j)
 		{
+			FILE *fh;
 			/* if the directory name is NULL then ignore */
 			if (hunspell_dict_dirs[j] == NULL) continue;
 
@@ -64,6 +70,18 @@ void * spellcheck_create(const char * lang)
 					spellcheck_lang_mapping[i+1]);
 			snprintf(hunspell_dic_file, FPATHLEN, "%s/%s.dic", hunspell_dict_dirs[j],
 					spellcheck_lang_mapping[i+1]);
+
+			/* Some versions of Hunspell_create() will succeed even if
+			 * there are no dictionary files. So test for permissions.
+			 */
+			fh = fopen(hunspell_aff_file, "r");
+			if (fh) fclose (fh);
+			else continue;
+
+			fh = fopen(hunspell_dic_file, "r");
+			if (fh) fclose (fh);
+			else continue;
+
 			h = Hunspell_create(hunspell_aff_file, hunspell_dic_file);
 			/* if hunspell handle was created break from loop */
 			if (h != NULL)
@@ -84,7 +102,7 @@ void spellcheck_destroy(void * chk)
 /**
  * Return boolean: 1 if spelling looks good, else zero
  */
-int spellcheck_test(void * chk, const char * word)
+Boolean spellcheck_test(void * chk, const char * word)
 {
 	if (NULL == chk)
 	{
@@ -92,7 +110,7 @@ int spellcheck_test(void * chk, const char * word)
 		return 0;
 	}
 
-	return Hunspell_spell((Hunhandle *)chk, word);
+	return (Boolean) Hunspell_spell((Hunhandle *)chk, word);
 }
 
 int spellcheck_suggest(void * chk, char ***sug, const char * word)
