@@ -89,15 +89,6 @@ char * strndup (const char *str, size_t size);
  */
 #define rand_r(seedp) rand()
 
-/* Users report that the default mbrtowc that comes with windows and/or
- * cygwin just doesn't work very well. So we use our own custom version,
- * instead.
- */
-size_t lg_mbrtowc(wchar_t *, const char *, size_t, mbstate_t *);
-#ifdef mbrtowc
-#undef mbrtowc
-#endif
-#define mbrtowc(w,s,n,x) lg_mbrtowc(w,s,n,x)
 #endif /* _MSC_VER || __MINGW32__ */
 
 /*
